@@ -26,13 +26,17 @@ impl ForwardPipeline {
     pub fn render_pass(
         &self,
         camera: &Camera,
-        objects: &[impl Object],
-        lights: &Lights,
+        objects: &[&dyn Object],
+        lights: &[&dyn Light],
     ) -> ThreeDResult<()> {
         render_pass(camera, objects, lights)
     }
 
-    pub fn depth_pass(&self, camera: &Camera, objects: &[impl Object]) -> ThreeDResult<()> {
+    ///
+    /// Render the distance from the camera to the objects in each pixel into a depth texture. Also, do not render transparent objects and objects outside the camera frustum.
+    /// Must be called in a render target render function, where a depth texture is bound, for example in the callback function of [Screen::write] or [DepthTargetTexture2D::write].
+    ///
+    pub fn depth_pass(&self, camera: &Camera, objects: &[&dyn Object]) -> ThreeDResult<()> {
         let depth_material = DepthMaterial {
             render_states: RenderStates {
                 write_mask: WriteMask::DEPTH,
@@ -44,15 +48,18 @@ impl ForwardPipeline {
             .iter()
             .filter(|o| !o.is_transparent() && camera.in_frustum(&o.aabb()))
         {
-            object.render_with_material(&depth_material, camera, &Lights::default())?;
+            object.render_with_material(&depth_material, camera, &[])?;
         }
         Ok(())
     }
 
+    ///
+    /// Creates a new [DepthTargetTexture2D], applies a [ForwardPipeline::depth_pass] and returns the texture.
+    ///
     pub fn depth_pass_texture(
         &self,
         camera: &Camera,
-        objects: &[impl Object],
+        objects: &[&dyn Object],
     ) -> ThreeDResult<DepthTargetTexture2D> {
         let mut depth_texture = DepthTargetTexture2D::new(
             &self.context,
